@@ -1,6 +1,6 @@
 package Map::Tube::Barcelona::Line::L3;
 
-$Map::Tube::Barcelona::Line::L3::VERSION   = '0.16';
+$Map::Tube::Barcelona::Line::L3::VERSION   = '0.17';
 $Map::Tube::Barcelona::Line::L3::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::Barcelona::Line::L3 - Barcelona Metro L3 Line stations.
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =encoding utf8
 
@@ -77,6 +77,22 @@ Barcelona Metro L3 Line stations.
 
 =back
 
+=head1 MAP
+
+Barcelona Metro Map: L<L3 Line|https://raw.githubusercontent.com/Manwar/Map-Tube-Barcelona/master/maps/L3.png>
+map generated by plugin L<Map::Tube::Plugin::Graph>.
+
+=begin html
+
+<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-Barcelona/master/maps/L3.png">
+<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-Barcelona/master/maps/L3.png"
+     alt    = "Barcelona Metro Map: L3 Line"
+     width  = "300px"
+     height = "600px"/>
+</a>
+
+=end html
+
 =head1 AUTHOR
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
